{pkgs, ...}:
{
  nix.settings.experimental-features = ["nix-command" "flakes"];

  time.timeZone = "Europe/Berlin";

  i18n.defaultLocale = "en_US.UTF-8";

  i18n.extraLocaleSettings = {
    LC_ADDRESS = "de_DE.UTF-8";
    LC_IDENTIFICATION = "de_DE.UTF-8";
    LC_MEASUREMENT = "de_DE.UTF-8";
    LC_MONETARY = "de_DE.UTF-8";
    LC_NAME = "de_DE.UTF-8";
    LC_NUMERIC = "de_DE.UTF-8";
    LC_PAPER = "de_DE.UTF-8";
    LC_TELEPHONE = "de_DE.UTF-8";
    LC_TIME = "de_DE.UTF-8";
  };

  console.keyMap = "de-latin1-nodeadkeys";
  nixpkgs.config.allowUnfree = true;

  environment.systemPackages = with pkgs; [
    bind
    cmake
    curl
    gcc
    git
    gnumake
    nmap
    tmux
    tree
    unzip
    wget
  ];

  hardware.keyboard.zsa.enable = true;

  programs = {
    fish.enable = true;
    gnupg.agent = {
        enable = true;
        enableSSHSupport = true;
    };
  };

  services = {
    fwupd.enable = true;
    resolved.enable = true;
    tailscale.enable = true;
    tailscale.useRoutingFeatures = "client";
  };
}
